@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponse.h 2507 2007-07-06 19:08:20Z svn $
+ * $Id: ApacheResponse.h 2588 2007-10-20 10:51:51Z svn $
  *****************************************************************************/
 
 #ifndef APACHE_RESPONSE_H
@@ -67,7 +67,7 @@ public:
 
         return content_type;
     };
-    static apr_size_t get_content_size(Handle *r)
+    static apr_uint64_t get_content_size(Handle *r)
     {
         const char *content_size;
 
@@ -77,7 +77,7 @@ public:
             return 0;
         }
 
-        return static_cast<apr_size_t>(apr_atoi64(content_size));
+        return apr_atoi64(content_size);
     };
     static const char *get_query(Handle *r)
     {
