@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Base64FileWriter.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: Base64FileWriter.h 2613 2007-10-28 02:47:22Z svn $
  *****************************************************************************/
 
 #ifndef BASE64_FILE_WRITER_H
@@ -86,7 +86,7 @@ public:
      *
      * @exception const char * 閉じるのに失敗した場合
      */
-    apr_size_t get_write_size() const
+    apr_uint64_t get_write_size() const
     {
         return writer_impl_.get_write_size();
     };
