@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: File.h 2548 2007-08-06 14:16:57Z svn $
+ * $Id: File.h 2621 2007-11-04 23:29:13Z svn $
  *****************************************************************************/
 
 #ifndef FILE_H
@@ -347,7 +347,7 @@ public:
     {
         REQUIRE_FILE_OPENDED;
 
-        if (apr_file_write(file_, buffer, size) != APR_SUCCESS) {
+        if (apr_file_write_full(file_, buffer, *size, size) != APR_SUCCESS) {
             THROW(MESSAGE_FILE_WRITE_FAILED);
         }
     };
