@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageEN.h 2564 2007-10-10 14:08:20Z svn $
+ * $Id: MessageEN.h 2604 2007-10-26 13:58:10Z svn $
  *****************************************************************************/
 
 #ifndef MESSAGE_EN_H
@@ -80,7 +80,7 @@
 #define MESSAGE_POST_IP_ADDRESS_GET_FAILED  "MESSAGE_POST_IP_ADDRESS_GET_FAILED"
 #define MESSAGE_POST_COMMENT_EMPTY          "MESSAGE_POST_COMMENT_EMPTY"
 #define MESSAGE_POST_COMMENT_TOO_LONG       "MESSAGE_POST_COMMENT_TOO_LONG"
-#define MESSAGE_POST_DATA_INVALID           "MESSAGE_POST_INVALID_DATA"
+#define MESSAGE_POST_DATA_INVALID           "MESSAGE_POST_DATA_INVALID"
 #define MESSAGE_POST_DOWNLOAD_PASS_TOO_LONG "MESSAGE_POST_DOWNLOAD_PASS_TOO_LONG"
 #define MESSAGE_POST_FILE_DIGEST_EMPTY      "MESSAGE_POST_FILE_DIGEST_EMPTY"
 #define MESSAGE_POST_FILE_DIGEST_TOO_LONG   "MESSAGE_POST_FILE_DIGEST_TOO_LONG"
