@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RequestReader.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: RequestReader.h 2585 2007-10-17 13:27:06Z svn $
  *****************************************************************************/
 
 #ifndef REQUEST_READER_H
@@ -55,6 +55,8 @@ public:
         apr_time_t end_time;
         /** その他のデータ */
         bool is_succeeded;
+        /** アイテム ID */
+        apr_uint32_t item_id;
     } post_progress_t;
 
     /**
