@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2525M 2007-08-26 12:59:14Z (ローカル) $
+ * $Id: WriteLocker.h 2525 2007-07-12 15:23:44Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -57,9 +57,6 @@ public:
 
         try_count = 1;
         while (1) {
-            // curr_status の read がループ外に押し出されるのを防ぐ
-            MEMORY_BARRIER;
-
             curr_status = apr_atomic_read(lock);
             if (get_read_count(curr_status) == NOT_LOCKED) {
                 new_status = curr_status | WRITE_LOCKED;
@@ -103,9 +100,6 @@ public:
         lock = lock_;
         try_count = 1;
         while (1) {
-            // curr_status の read がループ外に押し出されるのを防ぐ
-            MEMORY_BARRIER;
-
             curr_status = apr_atomic_read(lock);
             if (UNLIKELY(is_timeout(curr_status, status_))) {
                 // 他のスレッドにてタイムアウト処理がされた
