@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_util.h 2604 2007-10-26 13:58:10Z svn $
+ * $Id: uploader_util.h 2661 2007-11-16 16:42:38Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_UTIL_H
@@ -51,9 +51,6 @@ static const char ARG_SEPARATE_STR[]                = "/";
 
 static const char FILE_EXT_SEPARATOR[]              = ".";
 
-const char IE_NAME_ENCODING[]                       = "cp932";
-const char FIREFOX_NAME_ENCODING[]                  = "utf-8";
-
 const char *get_word(apr_pool_t *pool, const char **input,
                      const char delimiter);
 
@@ -62,11 +59,6 @@ void get_page_count(apr_size_t item_count, apr_size_t per_page_item_number,
 void get_page(apr_pool_t *pool, const char *arg, apr_size_t page_count,
               apr_size_t *page_no);
 
-
-const char *get_dispos_encoding(const char *user_agent);
-
-
-
 template<class R>
 void get_upload_param(apr_pool_t *pool, apr_array_header_t *content_array,
                       const char **file_name, const char **file_mime,
