@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2575 2007-10-13 08:17:57Z svn $
+ * $Id: Auxiliary.cpp 2661 2007-11-16 16:42:38Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,50 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2575 2007-10-13 08:17:57Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2661 2007-11-16 16:42:38Z svn $");
+
+const char *rfc2396_encode(apr_pool_t *pool, const char* str)
+{
+    static char hex[] = "0123456789ABCDEF";
+
+    apr_size_t conv_num;
+    char *encoded;
+    char *buffer;
+
+    conv_num = 0;
+    for (const char *plain = str; *plain != '\0'; plain++) {
+        if (isalnum(*plain) ||
+            (*plain == '.') || (*plain == '-') || (*plain == '_') ||
+            (*plain == ' ')) {
+            continue;
+        }
+        conv_num++;
+    }
+
+    if (conv_num == 0) {
+        return apr_pstrdup(pool, str);
+    }
+
+    APR_PCALLOC(encoded, char *, pool, strlen(str) + (conv_num*2) + 1);
+    buffer = encoded;
+
+    for (; *str != '\0'; str++) {
+        if (isalnum(*str) || (*str == '.') || (*str == '-') || (*str == '_')) {
+            *buffer++ = *str;
+        } else if (*str == ' ') {
+            *buffer++ = '+';
+        } else {
+            const unsigned char c = *str;
+
+            *buffer++ = '%';
+            *buffer++ = hex[c / 0x10];
+            *buffer++ = hex[c % 0x10];
+        }
+    }
+    *buffer = '\0';
+
+    return encoded;
+}
 
 void init_atomic(apr_pool_t *pool)
 {
