@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.cpp 2576 2007-10-13 19:18:17Z svn $
+ * $Id: DownloadFlowController.cpp 2616 2007-10-29 14:50:31Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2576 2007-10-13 19:18:17Z svn $");
+SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2616 2007-10-29 14:50:31Z svn $");
 
 const apr_size_t DownloadSession::DOWNLOAD_BUSY_SLEEP_SEC   = 5;
 
@@ -138,6 +138,25 @@ const char *DownloadFlowController::dump_list(apr_pool_t *pool,
     return dump;
 }
 
+DownloadSession::DownloadSession(DownloadFlowController *flow_controller,
+                                 apr_sockaddr_t *sockaddr)
+  : flow_controller_(flow_controller),
+    sockaddr_(sockaddr)
+{
+    is_valid_ = flow_controller_->add_session(sockaddr_);
+
+    if (!is_valid_) {
+        apr_sleep(apr_time_from_sec(DOWNLOAD_BUSY_SLEEP_SEC));
+    }
+}
+
+DownloadSession::~DownloadSession()
+{
+    if (is_valid_) {
+        flow_controller_->remove_session(sockaddr_);
+    }
+}
+
 
 /******************************************************************************
  * private メソッド
