@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2569 2007-10-12 16:23:04Z svn $
+ * $Id: UploadItemManager.cpp 2604 2007-10-26 13:58:10Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -48,7 +48,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2569 2007-10-12 16:23:04Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2604 2007-10-26 13:58:10Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -82,13 +82,14 @@ apr_size_t UploadItemManager::add(apr_pool_t *pool,
                                   const char *file_temp_path,
                                   const char *remove_pass,
                                   const char *download_pass,
-                                  const char *comment, const char *ip_address)
+                                  const char *comment, const char *code_pat,
+                                  const char *ip_address)
 {
     apr_size_t item_id;
 
     item_id = add_impl(pool, file_name, file_mime, file_size, file_digest,
                        file_temp_path, remove_pass, download_pass, comment,
-                       ip_address);
+                       code_pat, ip_address);
 
     sync_all_item_by_catches(pool);
 
@@ -254,6 +255,7 @@ apr_size_t UploadItemManager::add_impl(apr_pool_t *pool,
                                        const char *remove_pass,
                                        const char *download_pass,
                                        const char *comment,
+                                       const char *code_pat,
                                        const char *ip_address)
 {
     apr_size_t item_id;
@@ -270,7 +272,7 @@ apr_size_t UploadItemManager::add_impl(apr_pool_t *pool,
     uitem = UploadItem::get_instance
         (pool, item_id, item_index, file_size, current_time, ip_address,
          file_name, file_mime, file_digest, remove_pass, download_pass,
-         comment);
+         comment, code_pat);
 
     // 古いアイテムを削除
     while (item_list_->is_full(file_size)) {
